<?php
/**
 * This file implements the Creative Commons Render plugin for b2evolution. Version 2.1 2005/02/07
 *
 * This file may someday be an official part of the b2evolution project - {@link http://b2evolution.net/}
 * at which time I'll move the brackets to the line below.  Until then, tough. :P
 *
 * b2evolution - {@link http://b2evolution.net/}
 * Released under GNU GPL License - {@link http://b2evolution.net/about/license.html}
 * @copyright (c)2003-2004 by Francois PLANQUE - {@link http://fplanque.net/}
 *
 * @copyright (c)2005 by Daniel Morrison danielmorrison@mac.com
 *
 */
if( !defined('DB_USER') ) die( 'Please, do not access this page directly.' );

/**
 * Includes:
 */
require_once dirname(__FILE__).'/../renderer.class.php';
require_once dirname(__FILE__).'/../cc_license/cc_license.php';


/**
 * @package plugins
 */
class creativecommons_Rendererplugin extends RendererPlugin
{
	var $code = 'evo_ccor';
	var $name = 'Creative Commons';
	var $priority = 60;

	var $apply_when = 'always';
	var $apply_to_html = true; 
	var $apply_to_xml = false; 
	var $short_desc;
	var $long_desc;

	var $licenses;

	/**
	 * Constructor
	 *
	 * {@internal creativecommons_Rendererplugin::creativecommons_Rendererplugin(-)}}
	 */
	function creativecommons_Rendererplugin()
	{
		$this->short_desc = T_('Display Creative Commons Licences in posts.');
		$this->long_desc = T_('When used with the Creative Commons Toolbar plugin (required),
								This will display a Creative Commons License (and invisible metadata).');
		
		// preload the licenses, so we only do this once.
		$this->licenses = get_licenses();
	}


	/**
	 * Perform rendering
	 *
	 * {@internal creativecommons_Rendererplugin::render(-)}} 
	 *
	 * @param string content to render (by reference) / rendered content
	 * @param string Output format, see {@link format_to_output()}
	 * @return boolean true if we can render something for the required output format
	 */
	function render( & $content, $format )
	{
		if( ! parent::render( $content, $format ) )
		{	// We cannot render the required format
			return false;
		}
		
		
		
		// retreive license and display
		preg_match( '/<!-- Creative Commons License .*? -->/', $content, $match );
		
		if ( isset($match[0]) ) {
			preg_match( '/license:\S*/', $match[0], $licenses );
			preg_match( '/display:\S*/', $match[0], $displays );
			
			if ( isset($licenses[0]) && isset($displays[0]) ) {
				$uri = substr( $licenses[0], 8 );
				$display = substr( $displays[0], 8 );
				
				$license = find_license_by_uri($uri, $this->licenses);

				if ( $license ) {
				
					// Add locale to uri
					$lang = substr( locale_lang(false), 0, 2 );
					if ( $lang != 'en' )
						$uri = $license->uri . '/' . $lang;
					else 
						$uri = $license->uri;
					
					$html = '<!-- Creative Commons License --> <span class="cc_license">';
					
					if ( $display != 'hidden' ) {
						
						$html .= '<br />';
						
						if ( $display != 'text' ) {
							$html .= '<a href="'.$uri.'">';
							
							if ( $display == 'standard' ) {
								
								$html .= '<img alt="Creative Commons License" border="0" src="'.$license->logo_uri.'" />';
							}
							else if ( $display == 'symbols' ) {
								
								$symbolList = $license->get_symbols();
													
								foreach ( $symbolList as $symbol ) {
									$html .= '<img src="'.$symbol.'" alt="CC Symbol" />';
			
								}
							}
							
							$html .= '</a>';
							$html .= '<br />';
						}
						
						$html .= 'This post is licensed under a <a href="'.$uri.'">Creative Commons License</a>.';
						//$html .= '</p>';
					}
					
					$html .= '</span> <!-- /Creative Commons License -->';
					$html .= "<!--\n";
					$html .= $license->get_rdf();
					$html .= "\n-->";
					
					$content = preg_replace( '/<!-- Creative Commons License .*? -->/', $html, $content );
					
					return true;
				}
			}
		}
		
		return false;
	}
}

// Register the plugin:
$this->register( new creativecommons_Rendererplugin() );

?>